@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: io90pwmx.h,v 1.10 2007/12/12 04:36:54 arcanum Exp $ */
+/* $Id: io90pwmx.h,v 1.10.2.4 2008/08/14 00:08:00 arcanum Exp $ */
 
 /* avr/io90pwmx.h - definitions for AT90PWM2(B) and AT90PWM3(B) */
 
@@ -1321,6 +1321,7 @@
 #define RAMEND      0x02FF
 #define XRAMEND     0x02FF
 #define E2END       0x01FF
+#define E2PAGESIZE  4
 #define FLASHEND    0x0FFF
 
 
@@ -1329,36 +1330,36 @@
 #define FUSE_MEMORY_SIZE 3
 
 /* Low Fuse Byte */
-#define CKSEL0  ~_BV(0)  /* Select Clock Source */
-#define CKSEL1  ~_BV(1)  /* Select Clock Source */
-#define CKSEL2  ~_BV(2)  /* Select Clock Source */
-#define CKSEL3  ~_BV(3)  /* Select Clock Source */
-#define SUT0    ~_BV(4)  /* Select start-up time */
-#define SUT1    ~_BV(5)  /* Select start-up time */
-#define CKOUT   ~_BV(6)  /* Oscillator output option */
-#define CKDIV8  ~_BV(7)  /* Divide clock by 8 */
-#define LFUSE_DEFAULT (CKSEL0 & CKSEL2 & CKSEL3 & SUT0 & CKDIV8)
+#define FUSE_CKSEL0  (unsigned char)~_BV(0)  /* Select Clock Source */
+#define FUSE_CKSEL1  (unsigned char)~_BV(1)  /* Select Clock Source */
+#define FUSE_CKSEL2  (unsigned char)~_BV(2)  /* Select Clock Source */
+#define FUSE_CKSEL3  (unsigned char)~_BV(3)  /* Select Clock Source */
+#define FUSE_SUT0    (unsigned char)~_BV(4)  /* Select start-up time */
+#define FUSE_SUT1    (unsigned char)~_BV(5)  /* Select start-up time */
+#define FUSE_CKOUT   (unsigned char)~_BV(6)  /* Oscillator output option */
+#define FUSE_CKDIV8  (unsigned char)~_BV(7)  /* Divide clock by 8 */
+#define LFUSE_DEFAULT (FUSE_CKSEL0 & FUSE_CKSEL2 & FUSE_CKSEL3 & FUSE_SUT0 & FUSE_CKDIV8)
 
 /* High Fuse Byte */
-#define BODLEVEL0  ~_BV(0)
-#define BODLEVEL1  ~_BV(1)
-#define BODLEVEL2  ~_BV(2)
-#define EESAVE     ~_BV(3)  /* EEPROM memory is preserved through chip erase */
-#define WDTON      ~_BV(4)  /* Watchdog timer always on */
-#define SPIEN      ~_BV(5)  /* Enable Serial programming and Data Downloading */
-#define DWEN       ~_BV(6)  /* debugWIRE Enable */
-#define RSTDISBL   ~_BV(7)  /* External Reset Diasble */
-#define HFUSE_DEFAULT (SPIEN)
+#define FUSE_BODLEVEL0  (unsigned char)~_BV(0)
+#define FUSE_BODLEVEL1  (unsigned char)~_BV(1)
+#define FUSE_BODLEVEL2  (unsigned char)~_BV(2)
+#define FUSE_EESAVE     (unsigned char)~_BV(3)  /* EEPROM memory is preserved through chip erase */
+#define FUSE_WDTON      (unsigned char)~_BV(4)  /* Watchdog timer always on */
+#define FUSE_SPIEN      (unsigned char)~_BV(5)  /* Enable Serial programming and Data Downloading */
+#define FUSE_DWEN       (unsigned char)~_BV(6)  /* debugWIRE Enable */
+#define FUSE_RSTDISBL   (unsigned char)~_BV(7)  /* External Reset Diasble */
+#define HFUSE_DEFAULT (FUSE_SPIEN)
 
 /* Extended Fuse Byte */
-#define BOOTRST     ~_BV(0)
-#define BOOTSZ0     ~_BV(1)
-#define BOOTSZ1     ~_BV(2)
-#define PSCRV       ~_BV(4)
-#define PSC0RB      ~_BV(5)
-#define PSC1RB      ~_BV(6)
-#define PSC2RB      ~_BV(7)
-#define EFUSE_DEFAULT (BOOTSZ0 & BOOTSZ1)
+#define FUSE_BOOTRST     (unsigned char)~_BV(0)
+#define FUSE_BOOTSZ0     (unsigned char)~_BV(1)
+#define FUSE_BOOTSZ1     (unsigned char)~_BV(2)
+#define FUSE_PSCRV       (unsigned char)~_BV(4)
+#define FUSE_PSC0RB      (unsigned char)~_BV(5)
+#define FUSE_PSC1RB      (unsigned char)~_BV(6)
+#define FUSE_PSC2RB      (unsigned char)~_BV(7)
+#define EFUSE_DEFAULT (FUSE_BOOTSZ0 & FUSE_BOOTSZ1)
 
 
 /* Lock Bits */
