@@ -29,7 +29,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: wdt.h,v 1.44 2007/11/29 22:37:14 arcanum Exp $ */
+/* $Id: wdt.h,v 1.44.2.15 2008/11/03 04:13:19 arcanum Exp $ */
 
 /*
    avr/wdt.h - macros for AVR watchdog timer
@@ -70,7 +70,7 @@
     #include <stdint.h>
     #include <avr/wdt.h>
 
-    uint8_t mcusr_mirror _attribute_ ((section (".noinit")));
+    uint8_t mcusr_mirror __attribute__ ((section (".noinit")));
 
     void get_mcusr(void) \
       __attribute__((naked)) \
@@ -84,8 +84,8 @@
     \endcode
 
     Saving the value of MCUSR in \c mcusr_mirror is only needed if the
-    application later wants to examine the reset source, but clearing
-    in particular the watchdog reset flag before disabling the
+    application later wants to examine the reset source, but in particular, 
+    clearing the watchdog reset flag before disabling the
     watchdog is required, according to the datasheet.
 */
 
@@ -93,15 +93,17 @@
    \ingroup avr_watchdog
    Reset the watchdog timer.  When the watchdog timer is enabled,
    a call to this instruction is required before the timer expires,
-   otherwise a watchdog-initiated device reset will occur. */
+   otherwise a watchdog-initiated device reset will occur. 
+*/
 
 #define wdt_reset() __asm__ __volatile__ ("wdr")
 
+
 #if defined(WDP3)
 # define _WD_PS3_MASK       _BV(WDP3)
 #else
 # define _WD_PS3_MASK       0x00
-#endif /* WDP3 */
+#endif
 
 #if defined(WDTCSR)
 #  define _WD_CONTROL_REG     WDTCSR
@@ -116,38 +118,91 @@
 #endif
 
 
-#if defined(__AVR_AT90CAN128__) \
-|| defined(__AVR_AT90CAN32__) \
+/**
+   \ingroup avr_watchdog
+   Enable the watchdog timer, configuring it for expiry after
+   \c timeout (which is a combination of the \c WDP0 through
+   \c WDP2 bits to write into the \c WDTCR register; For those devices 
+   that have a \c WDTCSR register, it uses the combination of the \c WDP0 
+   through \c WDP3 bits).
+
+   See also the symbolic constants \c WDTO_15MS et al.
+*/
+
+
+#if || defined(__AVR_ATxmega64A1__) \
+|| defined(__AVR_ATxmega64A3__) \
+|| defined(__AVR_ATxmega128A1__) \
+|| defined(__AVR_ATxmega128A3__) \
+|| defined(__AVR_ATxmega256A3__) \
+|| defined(__AVR_ATxmega256A3B__)
+
+/*
+    wdt_enable(WDT_PER_8KCLK_gc);
+*/
+#define wdt_enable(value) \
+__asm__ __volatile__ ( \
+    "in __tmp_reg__, %0"  "\n\t" \
+    "out %1, %3"          "\n\t" \
+    "sts %2, %4"          "\n\t" \
+    "wdr"                 "\n\t" \
+    "out %0, __tmp_reg__" "\n\t" \
+    : \
+    : "M" (_SFR_MEM_ADDR(RAMPD)), \
+      "M" (_SFR_MEM_ADDR(CCP)), \
+      "M" (_SFR_MEM_ADDR(WDT_CTRL)), \
+      "r" ((uint8_t)0xD8), \
+      "r" ((uint8_t)(WDT_CEN_bm | WDT_ENABLE_bm | value)) \
+    : "r0" \
+)
+
+
+#elif defined(__AVR_AT90CAN32__) \
 || defined(__AVR_AT90CAN64__) \
-|| defined(__AVR_AT90USB82__) \
+|| defined(__AVR_AT90CAN128__) \
+|| defined(__AVR_AT90PWM1__) \
+|| defined(__AVR_AT90PWM2__) \
+|| defined(__AVR_AT90PWM216__) \
+|| defined(__AVR_AT90PWM2B__) \
+|| defined(__AVR_AT90PWM3__) \
+|| defined(__AVR_AT90PWM316__) \
+|| defined(__AVR_AT90PWM3B__) \
+|| defined(__AVR_AT90USB1286__) \
+|| defined(__AVR_AT90USB1287__) \
 || defined(__AVR_AT90USB162__) \
 || defined(__AVR_AT90USB646__) \
 || defined(__AVR_AT90USB647__) \
-|| defined(__AVR_AT90USB1286__) \
-|| defined(__AVR_AT90USB1287__) \
-|| defined(__AVR_ATmega48__) \
-|| defined(__AVR_ATmega48P__) \
-|| defined(__AVR_ATmega88__) \
-|| defined(__AVR_ATmega88P__) \
+|| defined(__AVR_AT90USB82__) \
+|| defined(__AVR_ATmega1280__) \
+|| defined(__AVR_ATmega1281__) \
 || defined(__AVR_ATmega1284P__) \
+|| defined(__AVR_ATmega164__) \
 || defined(__AVR_ATmega164P__) \
 || defined(__AVR_ATmega165__) \
 || defined(__AVR_ATmega165P__) \
 || defined(__AVR_ATmega168__) \
 || defined(__AVR_ATmega168P__) \
-|| defined(__AVR_ATmega328P__) \
 || defined(__AVR_ATmega169__) \
 || defined(__AVR_ATmega169P__) \
+|| defined(__AVR_ATmega16HVA__) \
+|| defined(__AVR_ATmega2560__) \
+|| defined(__AVR_ATmega2561__) \
+|| defined(__AVR_ATmega324__) \
 || defined(__AVR_ATmega324P__) \
 || defined(__AVR_ATmega325__) \
 || defined(__AVR_ATmega3250__) \
+|| defined(__AVR_ATmega328P__) \
 || defined(__AVR_ATmega329__) \
 || defined(__AVR_ATmega3290__) \
-|| defined(__AVR_ATmega325P__) \
-|| defined(__AVR_ATmega3250P__) \
-|| defined(__AVR_ATmega329P__) \
 || defined(__AVR_ATmega3290P__) \
+|| defined(__AVR_ATmega32C1__) \
+|| defined(__AVR_ATmega32HVB__) \
+|| defined(__AVR_ATmega32M1__) \
+|| defined(__AVR_ATmega32U4__) \
+|| defined(__AVR_ATmega32U6__) \
 || defined(__AVR_ATmega406__) \
+|| defined(__AVR_ATmega48__) \
+|| defined(__AVR_ATmega48P__) \
 || defined(__AVR_ATmega640__) \
 || defined(__AVR_ATmega644__) \
 || defined(__AVR_ATmega644P__) \
@@ -155,40 +210,30 @@
 || defined(__AVR_ATmega6450__) \
 || defined(__AVR_ATmega649__) \
 || defined(__AVR_ATmega6490__) \
-|| defined(__AVR_ATmega1280__) \
-|| defined(__AVR_ATmega1281__) \
-|| defined(__AVR_ATmega2560__) \
-|| defined(__AVR_ATmega2561__) \
 || defined(__AVR_ATmega8HVA__) \
-|| defined(__AVR_ATmega16HVA__) \
-|| defined(__AVR_ATmega32HVB__) \
-|| defined(__AVR_AT90PWM1__) \
-|| defined(__AVR_AT90PWM2__) \
-|| defined(__AVR_AT90PWM2B__) \
-|| defined(__AVR_AT90PWM3__) \
-|| defined(__AVR_AT90PWM3B__) \
-|| defined(__AVR_AT90PWM216__) \
-|| defined(__AVR_AT90PWM316__) \
+|| defined(__AVR_ATmega88__) \
+|| defined(__AVR_ATmega88P__) \
 || defined(__AVR_ATtiny48__) \
-|| defined(__AVR_ATtiny88__)
-
+|| defined(__AVR_ATtiny88__) \
+|| defined(__AVR_ATtiny167__)
 
+/* Use STS instruction. */
  
-#define _wdt_write(value)   \
-    __asm__ __volatile__ (  \
-        "in __tmp_reg__,__SREG__" "\n\t"    \
-        "cli" "\n\t"    \
-        "wdr" "\n\t"    \
-        "sts %0,%1" "\n\t"  \
-        "out __SREG__,__tmp_reg__" "\n\t"   \
-        "sts %0,%2" \
-        : /* no outputs */  \
-        : "M" (_SFR_MEM_ADDR(_WD_CONTROL_REG)), \
-        "r" (_BV(_WD_CHANGE_BIT) | _BV(WDE)), \
-        "r" ((uint8_t) ((value & 0x08 ? _WD_PS3_MASK : 0x00) | \
-            _BV(WDE) | (value & 0x07)) ) \
-        : "r0"  \
-    )
+#define wdt_enable(value)   \
+__asm__ __volatile__ (  \
+    "in __tmp_reg__,__SREG__" "\n\t"    \
+    "cli" "\n\t"    \
+    "wdr" "\n\t"    \
+    "sts %0,%1" "\n\t"  \
+    "out __SREG__,__tmp_reg__" "\n\t"   \
+    "sts %0,%2" "\n\t" \
+    : /* no outputs */  \
+    : "M" (_SFR_MEM_ADDR(_WD_CONTROL_REG)), \
+    "r" (_BV(_WD_CHANGE_BIT) | _BV(WDE)), \
+    "r" ((uint8_t) ((value & 0x08 ? _WD_PS3_MASK : 0x00) | \
+        _BV(WDE) | (value & 0x07)) ) \
+    : "r0"  \
+)
 
 #define wdt_disable() \
 __asm__ __volatile__ (  \
@@ -205,9 +250,11 @@ __asm__ __volatile__ (  \
 
 
     
-#else
+#else  
 
-#define _wdt_write(value)   \
+/* Use OUT instruction. */
+
+#define wdt_enable(value)   \
     __asm__ __volatile__ (  \
         "in __tmp_reg__,__SREG__" "\n\t"    \
         "cli" "\n\t"    \
@@ -241,21 +288,9 @@ __asm__ __volatile__ (  \
     "r" ((uint8_t)(_BV(_WD_CHANGE_BIT) | _BV(WDE))) \
     : "r0" \
 )
-    
+
 #endif
 
-/**
-   \ingroup avr_watchdog
-   Enable the watchdog timer, configuring it for expiry after
-   \c timeout (which is a combination of the \c WDP0 through
-   \c WDP2 bits to write into the \c WDTCR register; For those devices 
-   that have a \c WDTCSR register, it uses the combination of the \c WDP0 
-   through \c WDP3 bits).
-
-   See also the symbolic constants \c WDTO_15MS et al.
-*/
-#define wdt_enable(timeout) _wdt_write(timeout)
-
 
 
 /**
@@ -351,7 +386,7 @@ __asm__ __volatile__ (  \
     */
 #define WDTO_8S     9
 
-#endif
-
+#endif  /* defined(__DOXYGEN__) || defined(WDP3) */
+   
 
 #endif /* _AVR_WDT_H_ */
